"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectOperations = void 0;
/**
 * Functions to operate on objects
 */
class ObjectOperations {
    /**
     * Determines whether or not the given value is null or empty
     * @param value {object | string | undefined | null} Value to check if null or empty
     */
    IsNullOrEmpty(value) {
        switch (typeof (value)) {
            case 'object':
                const o = (value || {});
                return Object.keys(o).length === 0;
            case 'string':
                const s = (value || '');
                return s.length < 1;
            default:
                return true;
        }
    }
    /**
     * Determines whether or not the given value is null or whitespace
     * @param value {string | undefined | null} Value to check if null or whitespace
     */
    IsNullOrWhitespace(value) {
        return this.IsNullOrEmpty((value || '').trim());
    }
    /**
     * Converts to string
     * @param value {any} Value to convert to string
     */
    ToString(value) {
        switch (typeof (value)) {
            case 'boolean':
            case 'number':
            case 'string':
                return value.toString();
            case 'object':
                return JSON.stringify(value);
            default:
                return value || '';
        }
    }
}
exports.ObjectOperations = ObjectOperations;
//# sourceMappingURL=object-operations.js.map